/**
 * Class Vliegtuig - Beschrijft een vliegtuig met een aantal plaatsen.
 *
 * @author Dominiek Vandewalle
 * @version 2023-02-01
 */
public class Vliegtuig
{
    private Passagier[] zitplaatsen;

    /**
     * Constructor voor objecten van de klasse Vliegtuig.
     * @param   aantalZitplaatsen  het aantal beschikbare zitplaatsen in het vliegtuig
     */
    public Vliegtuig(int aantalZitplaatsen)
    {
        zitplaatsen = new Passagier [aantalZitplaatsen];
    }
    
    /**
     * Geeft het aantal zitplaatsen in het vliegtuig terug.
     * @return  het aantal zitplaatsen in het vliegtuig
     */
    public int aantalZitplaatsen()
    {
        return zitplaatsen.length;
    }
    
    /**
     * Berekent het aantal aanwezige passagiers in het vliegtuig.
     * @return het aantal passagiers
     */
    public int aantalPassagiers()
    {
        int aantal = 0;
        
        for(Passagier passagier: zitplaatsen)
        {
            if(passagier != null)
            {
                aantal++;
            }
        }
        
        return aantal;
    }
    
    /**
     * Berekent het aantal vrije zitplaatsen in het vliegtuig.
     * @return  het aantal vrije zitplaatsen
     */    
    public int aantalVrijePlaatsen()
    {
        int aantalVrij = 0;
        
        for(int index = 0; index < zitplaatsen.length; index++)
        {
            if(zitplaatsen[index] == null)
            {
                aantalVrij++;
            }
        }
        
        return aantalVrij;
    }
    
    /**
     * Laat een passagier plaatsnemen op een zitplaats in het vliegtuig indien 
     * die zitplaats vrij is.
     * @param   passagier       de passagier die in het vliegtuig stapt
     * @param   plaatsnummer    de zitplaats waar de passagier wenst te zitten
     */
    public void instappen(Passagier passagier, int plaatsnummer)
    {
        if(plaatsnummer >= 0 && plaatsnummer < zitplaatsen.length)
        {
            if(zitplaatsen[plaatsnummer] == null)
            {
                zitplaatsen[plaatsnummer] = passagier;
            }
        }
    }
    
    /**
     * Laat een passagier uit het vliegtuig stappen.
     * @param   passagier   de passagier die uitstapt
     */
    public void uitstappen(Passagier passagier)
    {
        int index = 0;
        
        while(index < zitplaatsen.length && zitplaatsen[index] != passagier)
        {
            index++;
        }
        
        if(index < zitplaatsen.length)
        {
            zitplaatsen[index] = null;
        }
    }
    
    /**
     * Toont de passagierslijst in het terminalvenster.
     */
    public void printPassagierslijst()
    {
        for(int index = 0; index < zitplaatsen.length; index++)
        {
            System.out.print(index + ": ");
            
            if(zitplaatsen[index] != null)
            {
                zitplaatsen[index].print();
            }
            else
            {
                System.out.println("-");
            }
        }
    }
}
