
/**
 * class Film - Beschrijft een review van een film
 *
 * @author Dominiek Vandewalle
 * @version 2023-01-05
 */
public class Film
{
    private String titel;
    private String beschrijving;// Korte beschrijving van de film
    private boolean oscarGewonnen;
    private int duimenOmhoog;
    private int duimenOmlaag;

    /**
     * Constructor voor objecten van de klasse Film.
     * @param   titel   de titel van de film
     */
    public Film(String titel)
    {
        this.titel = titel;
        beschrijving = "";
        oscarGewonnen = false;
        duimenOmhoog = 0;
        duimenOmlaag = 0;
    }

    /**
     * Geeft aan dat de film een Oscar gewonnen heeft.
     */
    public void winOscar()
    {
        oscarGewonnen = true;
    }

    /**
     * Verhoogt het aantal duimen omhoog met 1.
     */
    public void duimOmHoog()
    {
        duimenOmhoog++;
    }

    /**
     * Verhoogt het aantal duimen omlaag met 1.
     */
    public void duimOmlaag()
    {
        duimenOmlaag++;
    }

    /**
     * Geeft een update aan de beschrijving van de film.
     * @param   beschrijving    de nieuwe beschrijving van de film.
     */
    public void setBeschrijving(String beschrijving)
    {
        this.beschrijving = beschrijving;
    }

    /**
     * Berekent de score van de film op basis van het aantal duimen omhoog en omlaag.
     * @return  de score van de film op 10 punten
     */
    public double berekenScore()
    {
        double score = -1.0;

        if(duimenOmhoog + duimenOmlaag != 0)
        {
            score = 10.0 * duimenOmhoog / (duimenOmhoog + duimenOmlaag);
        }

        return score;
    }

    /**
     * Geeft het positieve verschil terug tussen het aantal duimen omhoog en omlaag.
     * @return  het positieve verschil tussen het aantal duimen omhoog en omlaag
     */
    public int duimenVerschil()
    {
        int verschil;

        if(duimenOmhoog > duimenOmlaag)
        {
            verschil = duimenOmhoog - duimenOmlaag;
        }
        else
        {
            verschil = duimenOmlaag - duimenOmhoog;
        }

        return verschil;
    }

    /**
     * Geeft op basis van het aantal duimen omhoog en omlaag een aanbeveling terug.
     * @return  een aanbeveling over de film
     */
    public String aanbeveling()
    {
        String suggestie = "";

        if(duimenOmhoog > 3 * duimenOmlaag  || oscarGewonnen)
        {
            suggestie = "Dit is een topfilm!";
        }
        else if(duimenOmlaag > 3 * duimenOmhoog && (duimenOmhoog + duimenOmlaag > 1000))
        {
            suggestie = "Deze film is niet voor iedereen weggelegd.";
        }
        else
        {
            suggestie = "Heel wat mensen vinden dit een goede film.";
        }

        return suggestie;
    }

    /**
     * Toont informatie over de film in het terminalvenster.
     */
    public void print()
    {
        String info = titel.toLowerCase() + "\n";

        if(oscarGewonnen)
        {
            info = titel.toUpperCase() + "\n";
        }

        if(! beschrijving.equals(""))
        {
            info += beschrijving.substring(0, beschrijving.length() / 2) + "...\n";
        }

        if(berekenScore() >= 0)
        {
            info += "Score: " + berekenScore() + "/10\n";
        }

        info += aanbeveling();

        System.out.println(info);
    }
}