/**
 * Beschrijft het gedrag van een cowboy in een computergame.
 * 
 * @author Dominiek Vandewalle
 * @version 2022-12-08
 */
public class Cowboy
{
    //velden
    private String naam;
    private double gezondheid;
    private Wapen wapen; //bv. pistol, rifle, revolver...

    /**
     * Constructor voor objecten van de klasse Cowboy.
     * Cowboys worden geboren met 100 procent gezondheid en slechts 1 leven
     * @param   naam    de naam van de cowboy
     */
    public Cowboy(String naam)
    {
        this.naam = naam;
        gezondheid = 100;
        wapen = null;
    }

    /**
     * Geeft de naam van de cowboy terug.
     * @return     de naam van de cowboy 
     */
    public String getNaam()
    {
        return naam;
    }

    /**
     * Geeft de gezondheid van de cowboy terug.
     * @return     de gezondheid van de cowboy
     */
    public double getGezondheid()
    {
        return gezondheid;
    }

    /**
     * Geeft het wapen van de cowboy terug.
     * @return     het wapen van de cowboy
     */
    public Wapen getWapen()
    {
        return wapen;
    }

    /**
     * Geeft aan of de cowboy al dan niet dood is.
     * @return     true indien de cowboy dood is, anders false
     */
    public boolean isDood()
    {
        return gezondheid == 0;
    }

    /**
     * Een andere cowboy aanvallen. Dit kan enkel indien de cowboy nog leeft en een wapen bezit om aan te vallen.
     * @param   tegenstander  de cowboy die aangevallen wordt
     */
    public void aanvallen(Cowboy tegenstander)
    {
        if(! isDood() && wapen != null && wapen.getMunitie() > 0)
        {
            wapen.schieten();
            tegenstander.geraakt(wapen);
        }
    }

    /**
     * Indien de cowboy geraakt wordt, dan verliest de cowboy een stukje van de gezondheid.
     * @param   wapenAanvaller het wapen van de aanvaller
     */
    public void geraakt(Wapen wapenAanvaller)
    {
        gezondheid -= wapenAanvaller.getDodelijkheid() * 100;

        if(gezondheid <= 0)
        {
            gezondheid = 0;
            this.wapen = null;
        }
    }

    /**
     * De cowboy krijgt een wapen om te kunnen schieten.
     * @param   wapen  het wapen dat de cowboy krijgt.
     */
    public void setWapen(Wapen wapen)
    {
        this.wapen = wapen;
    }

    /**
     * De cowboy krijgt een nog te initialiseren wapen.
     * @param   type                het type van het wapen
     * @param   dodelijkheid        de dodelijkheid van het wapen
     */
    public void nieuwWapen(String type, double dodelijkheid)
    {
        wapen = new Wapen(type, dodelijkheid);
    }

    /**
     * Het wapen weggooien.
     */
    public void wapenWeggooien()
    {
        wapen = null;
    }

    /**
     * Toont informatie over de cowboy in het terminalvenster.
     */
    public void print()
    {
        String info = "Naam: " + naam + "\n";
        info += "Gezondheid: " + gezondheid + "\n";

        System.out.print(info);

        if(wapen != null)
        {
            wapen.print();
        }
    }
}