import java.util.ArrayList;

/**
 * Beschrijft het gedrag van een cowboy in een computergame.
 * 
 * @author Dominiek Vandewalle
 * @version 2022-12-08
 */
public class Cowboy
{
    //velden
    private String naam;
    private ArrayList<Wapen> wapens;

    /**
     * Constructor voor objecten van de klasse Cowboy.
     * Cowboys worden geboren met 100 procent gezondheid en slechts 1 leven
     * @param   naam    de naam van de cowboy
     */
    public Cowboy(String naam)
    {
        this.naam = naam;
        wapens = new ArrayList<Wapen>();
    }

    /**
     * Geeft de naam van de cowboy terug.
     * @return     de naam van de cowboy 
     */
    public String getNaam()
    {
        return naam;
    }

    /**
     * Een wapen toevoegen aan de collectie van wapens.
     * @param   wapen   het wapen dat toegevoegd wordt aan de collectie van wapens.
     */
    public void wapenToevoegen(Wapen wapen)
    {
        wapens.add(wapen);
    }

    /**
     * Een wapen toevoegen aan de collectie van wapens.
     * @param   type            het type van het nieuwe wapen
     * @param   dodelijkheid    de dodelijkheid van het nieuwe wapen
     */
    public void nieuwWapenToevoegen(String type, double dodelijkheid)
    {
        wapens.add(new Wapen(type, dodelijkheid));
    }

    /**
     * Geeft het aantal wapens terug in de collectie van wapens.
     * @return  het aantal wapens in collectie van wapens
     */
    public int aantalWapens()
    {
        return wapens.size();
    }
    
    
    /**
     * Verwijdert het wapen op een gegeven index uit de collectie van wapens.
     * @param   index   de index van het wapen dat verwijderd wordt uit de collectie van wapens
     */
    public void wapenVerwijderen(int index)
    {
        if(index >= 0 && index < wapens.size())
        {
            wapens.remove(index);
        }
    }
    
    /**
     * Verwijdert het gegeven wapen uit de collectie van wapens.
     * @param   wapen   het wapen dat verwijderd wordt uit de collectie van wapens
     */
    public void wapenVerwijderen(Wapen wapen)
    {
            wapens.remove(wapen);
    }

    /**
     * Geeft het wapen terug op de gegeven index.
     * @param   index   de index van het wapen
     */
    public Wapen geefWapen(int index)
    {
        Wapen wapen = null;
        
        if(index >= 0 && index < wapens.size())
        {
            wapen = wapens.get(index);
        }
        
        return wapen;
    }
    
    /**
     * Toont informatie over de collectie van wapens in het terminalvenster.
     */
    public void print()
    {
        for(Wapen w : wapens)
        {
            w.print();
        }
    }
    
    /**
     * Berekent de totale hoeveelheid munitie in de collectie van wapens.
     * @return  de totale munitie in de collectie van wapens
     */
    public int totaleMunitie()
    {
        int totaal = 0;
        
        for(Wapen w: wapens)
        {
            totaal += w.getMunitie();
        }
        
        return totaal;
    }
    
    /**
     * Berekent het aantal wapens met munitie in de collectie
     * @return  het aantal geladen wapens
     */
    public int aantalGeladenWapens()
    {
        int aantal = 0;
        
        for(Wapen w : wapens)
        {
            if(w.getMunitie() > 0)
            {
                aantal++;
            }
        }
        
        return aantal;
    }
    
    /**
     * Geeft aan of een wapen van een gegeven type in de collectie van wapens aanwezig is.
     * @return  true indien een wapen van het gegeven type in de collectie van wapens aanwezig is, anders false
     */
    public boolean bezitWapen(String type)
    {
        int index = 0;
        while(index < wapens.size() && ! wapens.get(index).getType().equals(type))
        {
            index++;
        }
        
        return index < wapens.size();
    }
    
    /**
     * Geeft het eerste geladen wapen in de collectie van wapens.
     * @return  het eerste geladen wapen in de collectie van wapens
     */
    public Wapen zoekGeladenWapen()
    {
        Wapen gevonden = null;
        int index = 0;
        
        while(index < wapens.size() && wapens.get(index).getMunitie() == 0)
        {
            index++;
        }
        
        if(index < wapens.size())
        {
            gevonden = wapens.get(index);
        }
        
        return gevonden;
    }
}