/**
 * Beschrijft het gedrag van een cowboy in een computergame.
 * 
 * @author Dominiek Vandewalle
 * @version 2023-01-23
 */
public class Cowboy
{
    private String naam;
    private int gezondheid;
    private Game game;

    /**
     * Constructor voor objecten van de klasse Cowboy.
     * @param   naam    de naam van de cowboy
     */
    public Cowboy(String naam)
    {
        this.naam = naam;
        gezondheid = 100;
    }

    /**
     * Geeft de naam van de cowboy terug.
     * @return     de naam van de cowboy 
     */
    public String getNaam()
    {
        return naam;
    }

    /**
     * Geeft de gezondheid van de cowboy terug.
     * @return     de gezondheid van de cowboy
     */
    public int getGezondheid()
    {
        return gezondheid;
    }
    
    /**
     * Registeren bij een game.
     * @param   game    de game waar de cowboy aan wil deelnemen
     */
    public void aanmelden(Game game)
    {
        game.aanmelden(this);
        this.game = game;       
    }
    
    /**
     * Afmelden bij het spel waar aan deelgenomen wordt.
     */
    public void afmelden()
    {
        game.afmelden(this);
        game = null;
    }

    /**
     * Geeft aan of de cowboy al dan niet dood is.
     * @return     true indien de cowboy dood is, anders false
     */
    public boolean isDood()
    {
        return gezondheid == 0;
    }

    /**
     * Een cowboy aanvallen. Dit kan enkel indien de cowboy.
     * @param   tegenstander  de indiaan die aangevallen wordt
     */
    public void aanvallen(Cowboy tegenstander)
    {
        if(!isDood() && game != null 
                        && game.isAanZet(this) 
                        && game.isAangemeld(tegenstander))
        {
            tegenstander.geraakt();
        }
        else
        {
            System.out.print("de tegenstander is niet gekend | het is je beurt niet|");
            System.out.println(" niet aangemeld bij een game | Je bent dood");
        }
    }

    /**
     * Indien de cowboy geraakt wordt, dan verliest de cowboy een stukje van de gezondheid.
     */
    public void geraakt()
    {
        gezondheid = Math.max(0, gezondheid - 60);
        if(isDood())
        {
            afmelden();
        }
        else
        {
            game.setCowboyAanZet(this);
        }
    }

    /**
     * Toont informatie over de cowboy in het terminalvenster.
     */
    public void print()
    {
        String info = "Cowboy: " + naam + "\n";
        info += "Gezondheid: " + gezondheid;
        if(game != null)
        {
            info += "Game: " + game.getNaam();
        }
        System.out.println(info);
    }
}