import java.util.ArrayList;
/**
 * class Game - Beschrijft een spelletje waarbij cowboys elkaar kunnen beschieten.
 *
 * @author Dominiek Vandewalle
 * @version 2023-02-17
 */
public class Game
{
    private String naam;
    private Cowboy cowboyAanZet; // Cowboy die aan de beurt is
    private ArrayList<Cowboy> cowboys; // Cowboys die meespelen in het spel

    /**
     * Constructor voor objecten van de klasse Game
     * @param   naam    de naam van de game
     * @param   cowboy  de cowboy die het game aanmaakt
     */
    public Game(String naam, Cowboy cowboy)
    {
        this.naam = naam;
        cowboys = new ArrayList<Cowboy>();
        setCowboyAanZet(cowboy);
        aanmelden(cowboy);
    }

    /**
     * Geeft de naam van de game terug.
     * @return  de naam van de game
     */
    public String getNaam()
    {
        return naam;
    }

    /**
     * Verandert de cowboy die aan zet is.
     * @param   cowboyAanzet    de cowboy die aan zet is
     */
    public void setCowboyAanZet(Cowboy cowboyAanZet)
    {
        this.cowboyAanZet = cowboyAanZet;
    }

    /**
     * Registreert een cowboy bij het spel.
     * @param   cowboy  de cowboy die wenst deel te nemen aan het spel
     */
    public void aanmelden(Cowboy cowboy)
    {
        cowboys.add(cowboy);
    }

    /**
     * Meldt een cowboy af bij het spel.
     * @param   cowboy  de cowboy die het spel wenst te verlaten
     */
    public void afmelden(Cowboy cowboy)
    {
        cowboys.remove(cowboy);
        if(cowboy.isDood())
        {
            controleerOpWinnaar();
        }
    }

    /**
     * Geeft aan of de gegeven cowboy aan zet is
     * @param   cowboy  de cowboy waarvan je wenst te weten of die aan zet is
     */
    public boolean isAanZet(Cowboy cowboy)
    {
        return cowboy.equals(cowboyAanZet);
    }

    /**
     * Geeft aan of de cowboy geregistreerd is bij het spel.
     * @param   cowboy    de cowboy waarvan je wenst te weten of die geregistreerd is bij dit spel
     */
    public boolean isAangemeld(Cowboy cowboy)
    {
        return cowboys.contains(cowboy);
    }

    /**
     * Toont in het terminalvenster de enige speler in het spel als winnaar.
     */
    private void controleerOpWinnaar()
    {
        if(cowboys.size() == 1)
        {
            System.out.println("WINNAAR:");
            cowboyAanZet.print();
        }
    }

    /**
     * Toont in het terminalvenster een overzicht van het spel en spelers.
     */
    public void print()
    {
        System.out.println("Spel: " + naam + "\nOverzicht van spelers:");
        for(Cowboy c : cowboys)
        {
            c.print();
        }
        System.out.println("Speler aan de beurt:");
        cowboyAanZet.print();
    }
}