/**
 * Beschrijft het gedrag van een strijder in een computergame.
 * 
 * @author Dominiek Vandewalle
 * @version 2023-01-28
 */
public abstract class Strijder
{
    private String naam;
    private int gezondheid;

    /**
     * Constructor voor objecten van de klasse Strijder.
     * Strijders worden geboren met 100 procent gezondheid en slechts 1 leven
     * @param   naam    de naam van de strijder
     */
    public Strijder(String naam)
    {
        this.naam = naam;
        gezondheid = 100;
    }

    /**
     * Geeft de naam van de strijder terug.
     * @return     de naam van de strijder 
     */
    public String getNaam()
    {
        return naam;
    }

    /**
     * Geeft de gezondheid van de strijder terug.
     * @return     de gezondheid van de strijder
     */
    public int getGezondheid()
    {
        return gezondheid;
    }
    
    /**
     * Geeft de gezondheid van de strijder een nieuwe waarde.
     * @param   gezondheid  de nieuwe gezondheid van de strijder
     */
    public void setGezondheid(int gezondheid)
    {
        this.gezondheid = gezondheid;
    }

    /**
     * Geeft aan of de strijder al dan niet dood is.
     * @return     true indien de strijder dood is, anders false
     */
    public boolean isDood()
    {
        return gezondheid == 0;
    }

    /**
     * Een andere strijder aanvallen.
     * @param   tegenstander  de strijder die aangevallen wordt
     */
    public void aanvallen(Strijder tegenstander)
    {
        if(! isDood())
        {
            tegenstander.geraakt();
        }
    }

    /**
     * Indien de strijder geraakt wordt, dan verliest de strijder een stukje van de gezondheid.
     */
    public abstract void geraakt();
    
    /**
     * Toont informatie over de strijder in het terminalvenster.
     */
    public abstract void print();
}