/**
 * Beschrijft het gedrag van een indiaan in een computergame.
 * 
 * @author Dominiek Vandewalle
 * @version 2023-01-23
 */
public class Indiaan implements Strijder
{
    private String naam;
    private int gezondheid;

    /**
     * Constructor voor objecten van de klasse Indiaan.
     * Indianen worden geboren met 100 procent gezondheid en slechts 1 leven
     * @param   naam    de naam van de indiaan
     */
    public Indiaan(String naam)
    {
        this.naam = naam;
        gezondheid = 100;
    }

    /**
     * Geeft de naam van de indiaan terug.
     * @return     de naam van de indiaan 
     */
    public String getNaam()
    {
        return naam;
    }

    /**
     * Geeft de gezondheid van de indiaan terug.
     * @return     de gezondheid van de indiaan
     */
    public int getGezondheid()
    {
        return gezondheid;
    }

    /**
     * Geeft aan of de indiaan al dan niet dood is.
     * @return     true indien de indiaan dood is, anders false
     */
    public boolean isDood()
    {
        return gezondheid == 0;
    }

    /**
     * Een strijder aanvallen.
     * @param   tegenstander  de strijder die aangevallen wordt
     */
    public void aanvallen(Strijder tegenstander)
    {
        if(! isDood())
        {
            tegenstander.geraakt();
        }
    }

    /**
     * Indien de indiaan geraakt wordt, dan verliest de indiaan een stukje van de gezondheid.
     */
    public void geraakt()
    {
        gezondheid = Math.max(0, gezondheid - 40);
    }

    /**
     * Indien de indiaan een vredespijp met een strijder rookt, dan wordt een stukje gezondheid herwonnen.
     * Indien de indiaan alleen rookt, dan verliest de indiaan een stukje van de gezondheid.
     * @param   strijder  de strijder waarmee een vredespijp gerookt wordt of null indien alleen gerookt wordt.
     */
    public void rookVredespijp(Strijder strijder)
    {
        if(strijder != null)
        {
            gezondheid = Math.min(100, gezondheid + 20);
        }
        else
        {
            gezondheid = Math.max(0, gezondheid - 20);
        }
    }

    /**
     * Toont informatie over de indiaan in het terminalvenster.
     */
    public void print()
    {
        String info = "Indiaan: " + naam + "\n";
        info += "Gezondheid: " + gezondheid;
        System.out.println(info);
    }
}