import java.io.File;
import java.io.BufferedReader;
import java.io.FileReader;
import java.io.FileWriter;
import java.util.ArrayList;
import java.io.IOException;

/**
 * class Bestandstoegang - Regelt de toegang tot een bestand waarin cowboys opgeslagen worden
 *
 * @author Dominiek Vandewalle
 * @version 2023-02-13
 */
public class TxtCowboysDAO implements CowboysDAO
{
    private File bestand;

    /**
     * Constructor voor objecten van de klasse Bestandstoegang
     * @param   bestandsnaam    het bestand waaruit gelezen en waarin geschreven wordt
     */
    public TxtCowboysDAO()
    {
        bestand = new File("cowboys.txt");
    }

    /**
     * Leest cowboys uit het bestand in.
     * @return  een ArrayList met instanties van Cowboy
     */
    public ArrayList<Cowboy> lees()
    {
        ArrayList<Cowboy> cowboys = new ArrayList<Cowboy>();

        try(BufferedReader reader = new BufferedReader(new FileReader(bestand)))
        {           
            String regel = reader.readLine();
            while(regel != null)
            {
                cowboys.add(verwerkRegel(regel));
                regel = reader.readLine();
            }
        }
        catch(IOException e)
        {
            System.err.println(e.toString());
        }

        return cowboys;
    }

    /**
     * Schrijft een ArrayList met instanties van de klasse cowboy naar het bestand
     * @param   cowboys     een ArrayList met instanties van de klasse Cowboy
     */
    public void schrijf(ArrayList<Cowboy> cowboys)
    {
        try(FileWriter writer = new FileWriter(bestand))
        {
            for(Cowboy c : cowboys)
            {
                writer.write(c.getNaam() + " " + c.getGezondheid() + "\n");
            }
        }
        catch(IOException e)
        {
            System.err.println(e.toString());
        }
    }

    /**
     * Verwerkt een regel tekst uit een bestand tot een instantie van de klasse Cowboy.
     * @return  in instantie van de klasse Cowboy
     */
    private Cowboy verwerkRegel(String regel)
    {
        Cowboy cowboy = null;

        try
        {
            int indexSpatie = regel.indexOf(" ");
            String naam = regel.substring(0, indexSpatie);
            int gezondheid = Integer.parseInt(regel.substring(indexSpatie + 1));
            cowboy = new Cowboy(naam, gezondheid);       
        }
        catch(IndexOutOfBoundsException e)
        {
            System.err.println("Geen spatie gevonden - " + e.toString());
        }
        catch(NumberFormatException e)
        {
            System.err.println("Geen getal gevonden - " + e.toString());
        }
        catch(Exception e)
        {
            System.err.println("Er is iets fout gegaan - " + e.toString());
        }

        return cowboy;
    }
}